## $Id: documents.py 14178 2016-09-22 20:11:06Z henrik $
##
## Copyright (C) 2014 Uli Fouquet & Henrik Bettermann
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
##
"""
Customer document components.
"""
import grok
from zope.component.interfaces import IFactory
from zope.interface import implementedBy
from waeup.ikoba.utils.helpers import attrs_to_fields
from waeup.ikoba.customers.interfaces import ICustomerNavigation
from waeup.ikoba.customers.documents import CustomerDocumentBase
from ikobacustom.uniben.interfaces import MessageFactory as _
from ikobacustom.uniben.customers.interfaces import ISkeletonCustomerDocument


class SkeletonCustomerDocument(CustomerDocumentBase):
    """This is a sample customer document.
    """

    grok.implements(ISkeletonCustomerDocument, ICustomerNavigation)
    grok.provides(ISkeletonCustomerDocument)

    # Ikoba can store any number of files per Document object.
    # However, we highly recommend to associate and store
    # only one file per Document object. Thus the following
    # tuple should contain only a single filename string.
    filenames = ('sample',)

    form_fields_interface = ISkeletonCustomerDocument

SkeletonCustomerDocument = attrs_to_fields(SkeletonCustomerDocument)


# Customer documents must be importable. So we need a factory.
class SkeletonCustomerDocumentFactory(grok.GlobalUtility):
    """A factory for customer documents.
    """
    grok.implements(IFactory)
    grok.name(u'waeup.SkeletonCustomerDocument')
    title = u"Create a new document.",
    description = u"This factory instantiates new sample document instances."

    def __call__(self, *args, **kw):
        return SkeletonCustomerDocument(*args, **kw)

    def getInterfaces(self):
        return implementedBy(SkeletonCustomerDocument)
